pub type AppResult<T> = Result<T, AppError>;

#[derive(Debug, Fail)]
pub enum AppError {
    #[fail(display = "Execution failed: {}", _0)]
    StdErr(String),
    #[fail(display = "Config processing failed: {}", _0)]
    ParseError(String),
    #[fail(display = "Error was found: {}", _0)]
    RuntimeError(String),
}

impl From<std::io::Error> for AppError {
    fn from(err: std::io::Error) -> Self {
        Self::StdErr(err.to_string())
    }
}

impl From<serde_json::error::Error> for AppError {
    fn from(err: serde_json::error::Error) -> Self {
        Self::StdErr(err.to_string())
    }
}

impl From<regex::Error> for AppError {
    fn from(err: regex::Error) -> Self {
        Self::RuntimeError(err.to_string())
    }
}